@@ -1,21 +1,12 @@
 from typing import List
+import logging
 
 import pandas as pd
 
 from numerai_reports.data import Data
 
 
-def most_top_models(limit: int = 100, metric: str = "corr") -> pd.DataFrame:
-    if metric not in {'corr', 'fnc', 'mmc'}:
-        raise ValueError(f"invalid metric {metric}")
-    agg = {"corr_rep": "count", "model": lambda g: ", ".join(sorted(list(g)))}
-    subset = Data().leaderboard.sort_values(f'{metric}_rep', ascending=False)\
-                               .head(limit)
-    grouped = subset.groupby("account").agg(agg)
-    grouped.rename(columns={"corr_rep": "#models", "model": "models"},
-                   inplace=True)
-    grouped = grouped[grouped['#models'] > 1]
-    return grouped.sort_values("#models", ascending=False)
+logger = logging.getLogger(__name__)
 
 
 def all_positive(rounds: int = 20, metric: str = "corr") -> pd.DataFrame:
@@ -55,7 +46,7 @@ def payouts(models: List[str], groupby: str = "round") -> pd.DataFrame:
 def medals_leaderboard(limit: int = 10,
                        orderby: str = "total") -> pd.DataFrame:
     cols = ['gold', 'silver', 'bronze']
-    lb = Data().leaderboard.groupby("account")[cols].sum()
+    lb = Data().leaderboard.groupby("model")[cols].sum()
     lb['total'] = lb.sum(axis=1)
     lb.sort_values(orderby, ascending=False, inplace=True)
     return lb.astype(int).fillna(0).head(limit)
@@ -64,6 +55,10 @@ def medals_leaderboard(limit: int = 10,
 def models_of_account(model: str) -> List[str]:
     """return all models that belong the same account given a model name"""
     lb = Data().leaderboard
-    account = lb[lb['model'] == model]['account'].iloc[0]
+    try:
+        account = lb[lb['model'] == model]['account'].iloc[0]
+    except IndexError:
+        logger.warning(f"Unknown model {model}. Check spelling.")
+        return []
     res = lb[lb['account'] == account]['model'].unique()
     return list(res)
